
### soraya 
**Soraya** is a package for selecting the most important features that has been developed using an innovative **hybrid method**. Soraya identifies and selects the most relevant features for **regression** and **classification** tasks.


### Installation
To use the soraya package, the **Shap** package must be installed with "pip install shap". In general, the following libraries and packages are utilized by soraya:sklearn, pandas, numpy, tqdm, xgboost and shap.

**Note:** If you encounter any difficulties installing these packages on your local system, you can utilize the **Google colab** environment to install and utilize them seamlessly.

### How to use soraya
After installing soraya, simply execute the following two lines of code.
> from soraya import Main 

> print(Main())

